@@ -8,12 +8,13 @@ from pathlib import Path
 PACKAGE_DIR = Path(
     os.path.dirname(os.path.abspath(__file__))
 )  # This is the main package root
+CWD = Path(os.getcwd())
 
 # DIRECTORIES
 DIR_LOGS = PACKAGE_DIR / "logs"  # main dir for log-related files
 DIR_LOGS_OUTPUT = DIR_LOGS / "output"
 DIR_LOGS_CONFIG = DIR_LOGS / "config"
-DIR_DATA = PACKAGE_DIR / "data"
+DIR_DATA = CWD / "data"
 DIR_STATIC = PACKAGE_DIR / "static"
 
 # PATHS
